<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\Api;

use Locr\WordPress\Plugin\LocrMaps\DDD\Repositories\Icons as IconsRepository;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the shortcode.
 */
final class Icon {
	/**
	 * This function registers the all options route.
	 */
	public static function register_icon_route(): void {
		register_rest_route(
			route_namespace: 'locrmaps/icon',
			route: '/(?P<name>[a-zA-Z0-9-_]+)',
			args: array(
				'methods'             => \WP_REST_Server::READABLE,
				'callback'            => function ( \WP_REST_Request $request ) {
					$name = $request->get_param( 'name' );
					if ( is_null( $name ) ) {
						return new \WP_Error( 'bad_request', 'Missing "name" parameter.', array( 'status' => 400 ) );
					}
					if ( ! is_string( $name ) ) {
						return new \WP_Error( 'bad_request', 'Invalid "name" parameter.', array( 'status' => 400 ) );
					}

					$response = array();

					$icons_repository = new IconsRepository();
					$icon = $icons_repository->get_icon_by_name( $name );
					if ( is_null( $icon ) ) {
						return new \WP_Error( 'not_found', 'Icon not found.', array( 'status' => 404 ) );
					}

					$response = $icon->to_array();

					return rest_ensure_response( $response );
				},
				'permission_callback' => '__return_true',
			)
		);
	}
}
